@@ -1,10 +1,13 @@
+import logging
+
 from notion.block import CollectionViewPageBlock, PageBlock
 from progress.bar import Bar
 
 from enex2notion.enex_types import EvernoteNote
-from enex2notion.note_parser_dom import logger
 from enex2notion.note_uploader import upload_block
 
+logger = logging.getLogger(__name__)
+
 
 def get_import_root(client, title):
     for page in client.get_top_level_pages():
